from setuptools import setup, find_packages
from jupyter_packaging import (
    create_cmdclass,
    install_npm,
    ensure_targets,
    combine_commands,
)
import os

HERE = os.path.abspath(os.path.dirname(__file__))
name = "server_extension"

# Representative files that should exist after a successful build
ensured_targets = [
    os.path.join(HERE, "server_extension", "labextension", "package.json"),
]

data_files_spec = [
    ("share/jupyter/labextensions/server-extension", 
     "server_extension/labextension", "**"),
    ("etc/jupyter/jupyter_server_config.d",
     "jupyter-config", "server_extension.json"),
]

cmdclass = create_cmdclass("jsdeps", data_files_spec=data_files_spec)
cmdclass["jsdeps"] = combine_commands(
    install_npm(HERE, build_cmd="build:prod", npm=["jlpm"]),
    ensure_targets(ensured_targets),
)

setup(
    name=name,
    version="0.1.0",
    packages=find_packages(),
    package_data={
        "server_extension": [
            "handlers/*",
            "static/*",
            "*.json",
            "labextension/**",
        ],
    },
    include_package_data=True,
    author="Your Name",
    author_email="your.email@example.com",
    description="A JupyterLab extension for AI-powered chat",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    cmdclass=cmdclass,
    install_requires=[
        "jupyter_server>=1.6,<3",
        "jupyterlab>=4.0.0,<5.0.0",
        "python-dotenv",
        "google-generativeai",
        "torch",
        "torchvision",
        "torchaudio",
        "transformers",
        "beautifulsoup4",
        "requests",
        "jupyter_packaging>=0.7.9,<0.8.0"
    ],
    zip_safe=False,
    python_requires=">=3.7",
    platforms="Linux, Mac OS X, Windows",
    keywords=["Jupyter", "JupyterLab", "JupyterLab3"],
    classifiers=[
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Framework :: Jupyter",
    ],
    url="https://pypi.org/project/server-extension",
    project_urls={
        "Bug Reports": "https://github.com/gabrielchan/server-extension/issues",
        "Source": "https://github.com/gabrielchan/server-extension",
        "Documentation": "https://pypi.org/project/server-extension",
    }
)
